==> pandoc-3.5.tar.gz: pandoc-3.5/test/command/5116.md <==
```
% pandoc -t latex
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\pandocbounded{\includegraphics[keepaspectratio]{img.jpg}}
\caption{This is a figure.}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\caption{Demonstration of simple table syntax.}\tabularnewline
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endfirsthead
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```

```
% pandoc -t latex --figure-caption-position=above --table-caption-position=above
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\caption{This is a figure.}
\pandocbounded{\includegraphics[keepaspectratio]{img.jpg}}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\caption{Demonstration of simple table syntax.}\tabularnewline
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endfirsthead
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```

```
% pandoc -t latex --figure-caption-position=below --table-caption-position=below
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\pandocbounded{\includegraphics[keepaspectratio]{img.jpg}}
\caption{This is a figure.}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\tabularnewline
\caption{Demonstration of simple table syntax.}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```

==> pandoc-3.7.0.2.tar.gz: pandoc-3.7.0.2/test/command/5116.md <==
```
% pandoc -t latex
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\pandocbounded{\includegraphics[keepaspectratio,alt={This is a figure.}]{img.jpg}}
\caption{This is a figure.}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\caption{Demonstration of simple table syntax.}\tabularnewline
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endfirsthead
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```

```
% pandoc -t latex --figure-caption-position=above --table-caption-position=above
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\caption{This is a figure.}
\pandocbounded{\includegraphics[keepaspectratio,alt={This is a figure.}]{img.jpg}}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\caption{Demonstration of simple table syntax.}\tabularnewline
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endfirsthead
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```

```
% pandoc -t latex --figure-caption-position=below --table-caption-position=below
![This is a figure.](img.jpg)

  Right     Left     Center     Default
-------     ------ ----------   -------
     12     12        12            12
    123     123       123          123
      1     1          1             1

  :  Demonstration of simple table syntax.
^D
\begin{figure}
\centering
\pandocbounded{\includegraphics[keepaspectratio,alt={This is a figure.}]{img.jpg}}
\caption{This is a figure.}
\end{figure}

\begin{longtable}[]{@{}rlcl@{}}
\toprule\noalign{}
Right & Left & Center & Default \\
\midrule\noalign{}
\endhead
\bottomrule\noalign{}
\tabularnewline
\caption{Demonstration of simple table syntax.}
\endlastfoot
12 & 12 & 12 & 12 \\
123 & 123 & 123 & 123 \\
1 & 1 & 1 & 1 \\
\end{longtable}

```
